pub struct WpFractionalScaleV1 { /* private fields */ }Expand description
fractional scale interface to a wl_surface
An additional interface to a wl_surface object which allows the compositor to inform the client of the preferred scale.
See also the Request enum for this interface.
Implementations
Sourceimpl WpFractionalScaleV1
impl WpFractionalScaleV1
Sourcepub fn preferred_scale(&self, scale: u32)
pub fn preferred_scale(&self, scale: u32)
notify of new preferred scale
Notification of a new preferred scale for this surface that the compositor suggests that the client should use.
The sent scale is the numerator of a fraction with a denominator of 120.